import { createSlice } from '@reduxjs/toolkit';
import { setUserGoal, getConversationSummary, getRecommendedReply } from './talentChat.thunks';

const initialState = {
    goal: {
        status: 'idle', // 'idle' | 'loading' | 'succeeded' | 'failed'
        error: null,
        data: {
            id: null,
            content: null,
            created_at: null,
            updated_at: null,
        },
    },
    summary: {
        status: 'idle',
        error: null,
        data: {
            id: null,
            talent_email: null,
            conversation_id: null,
            summary: null,
            created_at: null,
            updated_at: null,
        },
    },
    recommendedReply: {
        status: 'idle',
        error: null,
        reply: null,
    },
};

const talentChatSlice = createSlice({
    name: 'talentChat',
    initialState,
    reducers: {},
    extraReducers: (builder) => {
        builder
            // Handle setUserGoal
            .addCase(setUserGoal.pending, (state) => {
                state.goal.status = 'loading';
            })
            .addCase(setUserGoal.fulfilled, (state, action) => {
                state.goal.status = 'succeeded';
                state.goal.data = action.payload.goal;
                state.goal.error = null;
            })
            .addCase(setUserGoal.rejected, (state, action) => {
                state.goal.status = 'failed';
                state.goal.error = action.error.message;
            })

            // Handle getConversationSummary
            .addCase(getConversationSummary.pending, (state) => {
                state.summary.status = 'loading';
            })
            .addCase(getConversationSummary.fulfilled, (state, action) => {
                state.summary.status = 'succeeded';
                state.summary.data = action.payload.summary;
                state.summary.error = null;
            })
            .addCase(getConversationSummary.rejected, (state, action) => {
                state.summary.status = 'failed';
                state.summary.error = action.error.message;
            })

            // Handle getRecommendedReply
            .addCase(getRecommendedReply.pending, (state) => {
                state.recommendedReply.status = 'loading';
            })
            .addCase(getRecommendedReply.fulfilled, (state, action) => {
                state.recommendedReply.status = 'succeeded';
                state.recommendedReply.reply = action.payload.reply;
                state.recommendedReply.error = null;
            })
            .addCase(getRecommendedReply.rejected, (state, action) => {
                state.recommendedReply.status = 'failed';
                state.recommendedReply.error = action.error.message;
            });
    },
});

export default talentChatSlice.reducer;
